<?php
defined( 'EXPRTZIN_BITPAY_LLMS_VERSION' ) || exit;

/**
 * @since 1.0
 * @version 1.0
 */
final class ExprtzIN_Bitpay_Llms {

	/**
	 * Singleton instance
	 */
	protected static $_instance = null;

	/**
	 * @return   ExprtzIN_Bitpay_Llms - Main instance
	 * @since    1.0.0
	 * @version  1.0.0
	 */
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	private function define( $name, $value ) {

		if ( ! defined( $name ) ) {
			define( $name, $value );
		}

	}

	private function file( $required_file ) {

		if ( file_exists( $required_file ) ) {
			require_once $required_file;
		}
	
	}

	/**
	 * ExprtzIN_Bitpay_Llms Constructor.
	 * @since 1.0
	 * @return void
	 */
	private function __construct() {

		$this->define_constants();
		$this->init();
		$this->load_textdomain();

	}

	/**
	 * Define LifterLMS Constants
	 *
	 * @since 1.0.0
	 * @return void
	 */
	private function define_constants() {

		$this->define( 'EXPRTZIN_BITPAY_LLMS_URL',        plugin_dir_url( EXPRTZIN_BITPAY_LLMS_FILE ) );
		$this->define( 'EXPRTZIN_BITPAY_LLMS_ASSETS_URL', EXPRTZIN_BITPAY_LLMS_URL . 'assets/' );

	}

    /**
     * Init ExprtzIN_Bitpay_Llms when WordPress Initialises.
     *
     * @since 1.0.0
     * @return void
     */
    public function init() {

        if ( class_exists('LifterLMS') ) {

            add_filter( 'lifterlms_payment_gateways', array( $this, 'add_exprtzin_bitpay_llms_gateway' ) );

            $this->includes();

            do_action( 'exprtzin_bitpay_llms_loaded' );

        }

    }

	/**
	 * Load Files
	 *
	 * @since 1.0
	 * @return void
	 */
	public function includes() {

		$this->file( EXPRTZIN_BITPAY_LLMS_DIR . 'includes/class-exprtzin-bitpay-llms-functions.php' );
		$this->file( EXPRTZIN_BITPAY_LLMS_DIR . 'includes/class-exprtzin-bitpay-llms-gateway.php' );
        $this->file( EXPRTZIN_BITPAY_LLMS_DIR . 'includes/class-exprtzin-bitpay-llms-notification.php' );

	}

    /**
     * Add the Gateway to LifterLMS
     **/
    public function add_exprtzin_bitpay_llms_gateway( $gateways ) {
        $gateways[] = apply_filters( 'exprtzin_bitpay_llms_gateway', 'ExprtzIN_Bitpay_Llms_Gateway' );
        return $gateways;
    }

	/**
	 * Localize
	 *
	 * @since 1.0
	 * @return void
	 */
	public function load_textdomain() {

		load_plugin_textdomain( 'expert-bitpay-gateway-lifterlms', false, dirname( plugin_basename( __FILE__ ) ) . '/languages' );

	}

}
