<?php

if ( ! defined('EXPRTZIN_BITPAY_LLMS_VERSION')) exit;

if( ! class_exists( 'ExprtzIN_Bitpay_Llms_Notification' ) ) :
	class ExprtzIN_Bitpay_Llms_Notification {

		/**
		 * Singleton instance
		 */
		protected static $_instance = null;

		/**
		 * @return   ExprtzIN_Bitpay_Llms_Notification - Main instance
		 * @since    1.0.0
		 * @version  1.0.0
		 */
		public static function instance() {
			if ( is_null( self::$_instance ) ) {
				self::$_instance = new self();
			}
			return self::$_instance;
		}

		/**
		 * ExprtzIN_Bitpay_Llms_Notification Constructor.
		 * @since 1.0
		 * @return void
		 */
		private function __construct() {

			add_action( 'init', array( $this, 'listen_notification' ), 10 );

		}

		public function listen_notification() {

			if ( isset( $_GET['action'] ) && $_GET['action'] == 'bitpay_notification' ) {

				$post = file_get_contents( "php://input" );

				update_option('bitpay_notification', 'here');

				if ( ! empty( $post ) ) {

					$ipn_data = json_decode( $post );
					
					if ( 
						! empty( $ipn_data->data->id ) && 
						! empty( $ipn_data->data->orderId ) 
					) {

						$invoice = $this->get_invoice( $ipn_data->data->id );

						if ( 
							! empty( $invoice['data']->status ) &&
							! empty( $invoice['data']->orderId ) &&
							$invoice['data']->orderId == $ipn_data->data->orderId &&
							$invoice['data']->status == 'confirmed' ||
							$invoice['data']->status == 'complete'
						) {
							
							$order = new LLMS_Order( intval( $invoice['data']->orderId ) );

							$order->record_transaction(
		                        array(
		                            'amount'             => $order->get('total'),
		                            'source_description' => __( 'Bitpay', 'expert-bitpay-gateway-lifterlms' ),
		                            'transaction_id'     => uniqid(),
		                            'status'             => 'llms-txn-succeeded',
		                            'payment_gateway'    => 'exprtzin_bitpay',
		                            'payment_type'       => 'single'
		                        )
		                    );
								
						}

					}

				}

	        }
			
		}

		public function get_invoice( $id ) {

			$host = 'https://bitpay.com/';

	        if ( get_exprtzin_bitpay_llms_option('test_mode_enabled') == 'yes' )
		        $host = 'https://test.bitpay.com/';

		    $token = get_exprtzin_bitpay_llms_option( 'token' );
			$url   = add_query_arg( 'token', $token, $host . 'invoices/' . $id );

	    	$response = wp_remote_get( 
	    		$url, 
	    		array(
				    'headers' => array( 
				    	'X-Accept-Version' => '2.0.0', 
				    	'Content-Type' => 'application/json' 
				    )
				) 
	    	);

	    	if ( ! empty( $response ) && ! is_wp_error( $response ) ) {
	        
	            $response = json_decode( $response['body'] );
	        
	            if ( ! empty( $response->data ) ) {
	                
	                return array( 'data' => $response->data );
	       
	            }
	            else {
	       
	                return array( 'error' => "Something went wrong." );
	       
	            }
	        
	        } 
	        elseif ( is_wp_error( $response ) ) {

			    return array( 'error' => "Something went wrong." );
			
			} 
			else {

			    return array( 'error' => "Something went wrong." );
			
			}

		}

	}
endif;

function exprtzin_bitpay_llms_notification() {
	return ExprtzIN_Bitpay_Llms_Notification::instance();
}
return exprtzin_bitpay_llms_notification();